==> grid_data_models-0.3.0.tar.gz: grid_data_models-0.3.0/src/gdm/distribution/components/distribution_vsource.py <==
"""This module contains interface for distribution substation."""

from typing import Annotated

from infrasys.quantities import Angle, Resistance, Voltage
from pydantic import Field

from gdm.distribution.components.distribution_bus import DistributionBus
from gdm.quantities import Reactance, PositiveVoltage
from gdm.distribution.distribution_enum import Phase
from gdm.constants import PINT_SCHEMA
from gdm.distribution.components.distribution_component import DistributionComponent
from gdm.distribution.components.distribution_feeder import DistributionFeeder
from gdm.distribution.components.distribution_substation import DistributionSubstation


class PhaseVoltageSourceEquipment(DistributionComponent):
    """Interface for phase voltage source."""

    r0: Annotated[Resistance, PINT_SCHEMA, Field(..., description="Zero sequence resistance.")]
    r1: Annotated[Resistance, PINT_SCHEMA, Field(..., description="Positive sequence resistance.")]
    x0: Annotated[Reactance, PINT_SCHEMA, Field(..., description="Zero sequence reactance.")]
    x1: Annotated[Reactance, PINT_SCHEMA, Field(..., description="Positive sequence reactane.")]
    voltage: Annotated[
        Voltage, PINT_SCHEMA, Field(..., description="Voltage for this substation.")
    ]
    angle: Annotated[Angle, PINT_SCHEMA, Field(..., description="Angle for the voltage")]

    @classmethod
    def example(cls) -> "PhaseVoltageSourceEquipment":
        """Example for phase voltage source."""
        return PhaseVoltageSourceEquipment(
            name="phase-source-1",
            r0=Resistance(0.001, "ohm"),
            r1=Resistance(0.001, "ohm"),
            x0=Reactance(0.001, "ohm"),
            x1=Reactance(0.001, "ohm"),
            voltage=PositiveVoltage(132.0, "kilovolt"),
            angle=Angle(180, "degree"),
            substation=DistributionSubstation.example(),
            feeder=DistributionFeeder.example(),
        )


class VoltageSourceEquipment(DistributionComponent):
    """Interface for voltage source model."""

    sources: Annotated[
        list[PhaseVoltageSourceEquipment],
        Field(
            ...,
            description="list of single phase voltage sources",
        ),
    ]

    @classmethod
    def example(cls) -> "VoltageSourceEquipment":
        """Example for voltage source model."""
        return VoltageSourceEquipment(
            name="Voltage Source 1", sources=[PhaseVoltageSourceEquipment.example()] * 3
        )


class DistributionVoltageSource(DistributionComponent):
    """Interface for distribution substation."""

    bus: Annotated[
        DistributionBus,
        Field(
            ...,
            description="Distribution bus to which this voltage source is connected to.",
        ),
    ]
    phases: Annotated[list[Phase], Field(..., description="Phase to which this is connected to.")]
    equipment: Annotated[VoltageSourceEquipment, Field(..., description="Voltage source model.")]

    @classmethod
    def example(cls) -> "DistributionVoltageSource":
        """Example for distribution voltage source."""
        return DistributionVoltageSource(
            name="DistributionVoltageSource1",
            bus=DistributionBus.example(),
            phases=[Phase.A, Phase.B, Phase.C],
            substation=DistributionSubstation.example(),
            feeder=DistributionFeeder.example(),
            equipment=VoltageSourceEquipment.example(),
        )

==> grid_data_models-1.3.3.tar.gz: grid_data_models-1.3.3/src/gdm/distribution/components/distribution_vsource.py <==
"""This module contains interface for distribution substation."""

from typing import Annotated

from pydantic import Field

from gdm.distribution.components.distribution_bus import DistributionBus
from gdm.distribution.distribution_enum import Phase
from gdm.distribution.components.base.distribution_component_base import DistributionComponentBase
from gdm.distribution.components.distribution_feeder import DistributionFeeder
from gdm.distribution.components.distribution_substation import DistributionSubstation
from gdm.distribution.equipment.voltagesource_equipment import VoltageSourceEquipment


class DistributionVoltageSource(DistributionComponentBase):
    """Interface for distribution substation."""

    bus: Annotated[
        DistributionBus,
        Field(
            ...,
            description="Distribution bus to which this voltage source is connected to.",
        ),
    ]
    phases: Annotated[list[Phase], Field(..., description="Phase to which this is connected to.")]
    equipment: Annotated[VoltageSourceEquipment, Field(..., description="Voltage source model.")]

    @classmethod
    def example(cls) -> "DistributionVoltageSource":
        """Example for distribution voltage source."""
        return DistributionVoltageSource(
            name="DistributionVoltageSource1",
            bus=DistributionBus.example(),
            phases=[Phase.A, Phase.B, Phase.C],
            substation=DistributionSubstation.example(),
            feeder=DistributionFeeder.example(),
            equipment=VoltageSourceEquipment.example(),
        )
